%  ##############################################################################
%  # This file is part of STEAM, version 1.0 (pre-alpha) .                      #
%  #                                                                            #
%  # STEAM is free software: you can  redistribute it and/or  modify it  under  #
%  # the terms of the  Ecliplse Publice License as  published by the            #
%  # Eclipse  Foundation, version 1.0.                                          #
%  #                                                                            #
%  # STEAM is  distributed  in the hope  that it will  be useful, but  WITHOUT  #
%  # ANY  WARRANTY; without  even the  implied warranty  of MERCHANTABILITY  or #
%  # FITNESS  FOR A PARTICULAR  PURPOSE. See the Eclipse Public License for     #
%  # more details. Visit <http://www.eclipse.org/legal/epl-v10.html>.           #
%  #                                                                            #
%  #                             Copyright (C) 2014                             #
%  #   Embedded Systems Laboratory - Ecole Polytechnique Federale de Lausanne   #
%  #                            All Rights Reserved.                            #
%  #                                                                            #
%  # Authors: Arvind Sridhar                                                    #
%  #          David Atienza                                                     #
%  #                                                                            #
%  # For any comment, suggestion or request  about STEAM, please  contact       #
%  #                                                                            #
%  # EPFL-STI-IEL-ESL                                                           #
%  # Batiment ELG, ELG 130                                                      #
%  # Station 11                                                                 #
%  # 1015 Lausanne, Switzerland           Url  : http://esl.epfl.ch/STEAM       #
%  ##############################################################################
function [dP_mom dPdz_frict]=Pressuredrop_from_correlations(G,x,x_prev,T,Dh,ref,flow_type,dpdz_frict_correlation);


% zero pressure drop
if strcmp(flow_type,'nodrop')
    dP_mom=0;
    dPdz_frict=0; % initial assumption

% Homogenous flow
elseif strcmp(flow_type,'homogenous')
    rho_g=refpropm('D','T',T,'Q',1,ref);
    rho_l=refpropm('D','T',T,'Q',0,ref);

    void_frac_cur=1/(1+(1-x)*rho_g/(x*rho_l));
    void_frac_prev=1/(1+(1-x_prev)*rho_g/(x_prev*rho_l));

    rho_avg_cur=rho_l*(1-void_frac_cur)+rho_g*void_frac_cur;
    rho_avg_prev=rho_l*(1-void_frac_prev)+rho_g*void_frac_prev;

    dP_mom=G*(1/rho_avg_cur-1/rho_avg_prev)*1e-3; % momentum pressure drop in kPa

    mu_avg=x*refpropm('V','T',T,'Q',1,ref)+(1-x)*refpropm('V','T',T,'Q',0,ref);
    Re=G*Dh/mu_avg; % Reynolds number;
    ftp=0.079/Re^0.25; % friction factor

    dPdz_frict=2*ftp*G^2/(Dh*rho_avg_cur)*1e-3;% local frictional pressure drop in kPa/m

% Stratified flow
elseif strcmp(flow_type,'stratified')
    g=9.8; % gravitational acceleration in m/s2
    sigma=refpropm('I','T',T,'Q',x,ref); % surface tension in N/m (remains independent of vapor quality)
    
    rho_g=refpropm('D','T',T,'Q',1,ref);
    rho_l=refpropm('D','T',T,'Q',0,ref);
    
    if x==0
        void_frac_cur=0;
    else
        void_frac_cur=(x/rho_g)*((1+0.12*(1-x))*(x/rho_g+(1-x)/rho_l)+(1.18*(1-x)*(g*sigma*(rho_l-rho_g))^0.25)/(G^2*rho_l^0.5))^-1;
    end
    if x_prev==0;
        void_frac_prev=0;
    else
        void_frac_prev=(x_prev/rho_g)*((1+0.12*(1-x_prev))*(x_prev/rho_g+(1-x_prev)/rho_l)+(1.18*(1-x_prev)*(g*sigma*(rho_l-rho_g))^0.25)/(G^2*rho_l^0.5))^-1;
    end
    
    if void_frac_cur==0
        term_cur=1/rho_l;
    else
        term_cur=(1-x)^2/(rho_l*(1-void_frac_cur))+x^2/(rho_g*void_frac_cur);
    end
    if void_frac_prev==0
        term_prev=1/rho_l;
    else
        term_prev=(1-x_prev)^2/(rho_l*(1-void_frac_prev))+x_prev^2/(rho_g*void_frac_prev);    
    end
    dP_mom=G^2*(term_cur-term_prev)*1e-3;
    
    
    % frictional pressure drop
    if strcmp(dpdz_frict_correlation,'friedel')
        mu_l=refpropm('V','T',T,'Q',0,ref);
        Re_l=G*Dh/mu_l % liquid Reynolds number;
        f_l=0.079/Re_l^0.25; % liquid friction factor
        
        dpdz_l=4*f_l*G^2/(Dh*2*rho_l);
        
        rho_tp=(x/rho_g+(1-x)/rho_l)^-1;
        mu_g=refpropm('V','T',T,'Q',1,ref);
        Re_g=G*Dh/mu_g % vapor Reynolds number;
        f_g=0.079/Re_g^0.25; % vapor friction factor
        
        Fr_H=G^2/(g*Dh*rho_tp^2);
        E=(1-x)^2+x^2*(rho_l*f_g)/(rho_g*f_l);
        F=x^0.78*(1-x)^0.224;
        H=(rho_l/rho_g)^0.91*(mu_g/mu_l)^0.19*(1-mu_g/mu_l)^0.7;
        We_l=G^2*Dh/(sigma*rho_tp);
        
        Phi_fr_2=E+3.24*F*H/(Fr_H^0.045*We_l^0.035);
        
        dPdz_frict=dpdz_l*Phi_fr_2*1e-3; % local frictional pressure drop in kPa/m
    elseif strcmp(dpdz_frict_correlation,'martinelli');
        
        
        mu_l=refpropm('V','T',T,'Q',0,ref);
        Re_l=G*(1-x)*Dh/mu_l; % liquid Reynolds number;
        
        mu_g=refpropm('V','T',T,'Q',1,ref);
        Re_g=G*x*Dh/mu_g; % vapor Reynolds number;
        
        Xtt=((1-x)/x)^0.9*(rho_g/rho_l)^0.5*(mu_l/mu_g)^0.1; % Martinelli paramter for turbulen-turbulent flow
        
        % value of the constant C
        if Re_l>=2300 && Re_g>=2300    % turbulent-turbulent flow
            C=20;
        elseif Re_l<2300 && Re_g>=2300 % laminar-turbulent flow
            C=12;
        elseif Re_l>=2300 && Re_g<2300 % turbulent-laminar flow
            C=10;
        else                           % laminar-laminar flow
            C=5;
        end
        
        if Re_l>4000
            
            Phi_ltt_2=1+C/Xtt+1/Xtt^2; % Two-phase multiplier
           
            f_l=0.079/Re_l^0.25; % liquid friction factor
            dpdz_l=4*f_l*G^2*(1-x)^2/(Dh*2*rho_l); % liquid pressure drop
            
            dPdz_frict=dpdz_l*Phi_ltt_2*1e-3; % local frictional pressure drop in kPa/m
        else
            Phi_gtt_2=1+C*Xtt+Xtt^2; % Two-phase multiplier
           
            f_g=0.079/Re_g^0.25; % liquid friction factor
            dpdz_g=4*f_g*G^2*x^2/(Dh*2*rho_g); % liquid pressure drop
            
            dPdz_frict=dpdz_g*Phi_gtt_2*1e-3; % local frictional pressure drop in kPa/m
        end
        
        
    elseif strcmp(dpdz_frict_correlation,'gronnerud')
        mu_l=refpropm('V','T',T,'Q',0,ref);
        Re_l=G*Dh/mu_l; % liquid Reynolds number;
        f_l=0.079/Re_l^0.25; % liquid friction factor
        
        dpdz_l=4*f_l*G^2/(Dh*2*rho_l);
        
        Fr_l=G^2/(g*Dh*rho_l^2); % Froud number
        
        if Fr_l>=1
            f_Fr=1;
        else
            f_Fr=Fr_l^0.3+0.0055*(log(1/Fr_l))^2;
        end
        
        dpdz_Fr=f_Fr*(x+4*(x^1.8-x^10*f_Fr^0.5));                                                                                                                                                                                                                                                                                                                     
        
        mu_g=refpropm('V','T',T,'Q',1,ref);
        Phi_gd=1+dpdz_Fr*((rho_l/rho_g)/(mu_l/mu_g)^0.25-1);
        dPdz_frict=dpdz_l*Phi_gd*1e-3;
        
    elseif strcmp(dpdz_frict_correlation,'chisholm')
        mu_l=refpropm('V','T',T,'Q',0,ref);
        Re_l=G*Dh/mu_l; % liquid Reynolds number;
        % liquid friction factor
        if Re_l>=2000
            f_l=0.079/Re_l^0.25;
        else
            f_l=16/Re_l;
        end
        dpdz_l=2*f_l*G^2/(Dh*rho_l);
        
        mu_g=refpropm('V','T',T,'Q',1,ref);
        Re_g=G*Dh/mu_g; % liquid Reynolds number;
        % liquid friction factor
        if Re_g>=2000
            f_g=0.079/Re_g^0.25;
        else
            f_g=16/Re_g;
        end
        dpdz_g=2*f_g*G^2/(Dh*rho_g);
        
        Y2=dpdz_g/dpdz_l;
        Y=sqrt(Y2);
        
        if Y>=0 && Y<9.5
            if G>=1900
                B=55/sqrt(G);
            elseif G>=500 && G<1900
                B=2400/G;
            else
                B=4.8;
            end
        elseif Y>=9.5 && Y<28
            if G<=600
                B=520/(Y*sqrt(G));
            else
                B=21/Y;
            end
        else
            B=15000/(Y2*sqrt(G));
        end
        
        n=0.25;
        Phi_ch_2=1+(Y^2-1)*(B*x^((2-n)/2)*(1-x)^((2-n)/2)+x^(2-n));
        
        dPdz_frict=dpdz_l*Phi_ch_2*1e-3;
        
       
        
    elseif strcmp(dpdz_frict_correlation,'bankoff')
        mu_l=refpropm('V','T',T,'Q',0,ref);
        Re_l=G*Dh/mu_l; % liquid Reynolds number;
        % liquid friction factor
        if Re_l>=2000
            f_l=0.079/Re_l^0.25;
        else
            f_l=16/Re_l;
        end
        dpdz_l=2*f_l*G^2/(Dh*rho_l);
        
        gamma=(0.71+2.35*(rho_g/rho_l))/(1+((1-x)/x)*(rho_g/rho_l));
        
        Phi_bf=(1/(1-x))*(1-gamma*(1-rho_g/rho_l))^(3/7)*(1+x*(rho_l/rho_g-1));
        
        dPdz_frict=dpdz_l*Phi_bf^(7/4)*1e-3;
        
    elseif strcmp(dpdz_frict_correlation,'chawla')
        mu_g=refpropm('V','T',T,'Q',1,ref);
        Re_g=G*Dh/mu_g; % liquid Reynolds number;
        % liquid friction factor
        if Re_g>=2000
            f_g=0.079/Re_g^0.25;
        else
            f_g=16/Re_g;
        end
        dpdz_g=2*f_g*G^2/(Dh*rho_g);
        
        rho_h=(x/rho_g+(1-x)/rho_l)^-1;
        Fr_h=G^2/(g*Dh*rho_h^2);
        mu_l=refpropm('V','T',T,'Q',0,ref);
        
        S=(9.1*(((1-x)/x)*(Re_g*Fr_h)^-0.167*(rho_l/rho_g)^-0.9*(mu_l/mu_g)^-0.5))^-1;
        
        Phi_chawla=x^1.75*(1+S*(((1-x)/x)*(rho_g/rho_l)))^2.375;
        
        dPdz_frict=dpdz_g*Phi_chawla*1e-3;
        
    elseif strcmp(dpdz_frict_correlation,'muller')
        mu_l=refpropm('V','T',T,'Q',0,ref);
        Re_l=G*Dh/mu_l; % liquid Reynolds number;
        % liquid friction factor
        if Re_l>=2000
            f_l=0.079/Re_l^0.25;
        else
            f_l=16/Re_l;
        end
        A=2*f_l*G^2/(Dh*rho_l);
        
        mu_g=refpropm('V','T',T,'Q',1,ref);
        Re_g=G*Dh/mu_g; % liquid Reynolds number;
        % liquid friction factor
        if Re_g>=1187
            f_g=0.079/Re_g^0.25;
        else
            f_g=16/Re_g;
        end
        B=2*f_g*G^2/(Dh*rho_g);
        
        G_muller=A+2*(B-A)*x;
        
        dPdz_frict=(G_muller*(1-x)^(1/3)+B*x^3)*1e-3;
        
    end
    
        
    
    
end

